# -*- coding: utf-8 -*-
import json
from datetime import datetime

from odoo import http
from odoo.http import request
from odoo.exceptions import UserError
from odoo.addons.saas_worker.util import from_role


#----------------------------------------------------------
# E-commerce controller
#----------------------------------------------------------
class EcommerceController(http.Controller):

    #--------------------------------------------------------------------------
    # Route called by Odoo to fetch module informations
    #--------------------------------------------------------------------------
    @from_role('accounts')
    @http.route('/apps/odoo_module_info', auth='public', methods=['POST'], csrf=False)
    def odoo_module_info(self, module_ids, order_id, order_name, user_id=None, **kw):
        vals_list = []
        Users = request.env['res.users'].sudo()
        if module_ids and order_id:
            module_ids = json.loads(module_ids)
            referrer_module_id = module_ids[0]
            for module_id in module_ids:
                module = request.env['loempia.module'].sudo().browse(int(module_id))
                template = module.template_id
                if not module.exists():
                    raise UserError("The module corresponding to this id:%s doesn\'t exist" % module_id)
                module = module._get_commercial_series_module_id()
                version = ' for version %s' % module.series_id.name
                if module == template.latest_version_before_series13:
                    version += ' or older'

                module_values = {
                    'name': module.shortdesc + ' by %s %s' % (module.author, version),
                    # 'description_sale': module.description_sale,
                    'default_code': module.name,
                    'apps_reference': str(module.id),
                    'image': module.icon_image.decode(),
                    'oauth_uid': module.repo_id.maintainer_id.oauth_uid,
                    'list_price': module.price_single,
                    # Need to transmit the lastest module id on 'accounts' for now
                    'active': module.status in ['approved', 'invalid'],
                    'website_published': True,
                    'digital_content': True,
                    'product_id': module.product_id,
                }

                vals_list.append(module_values)

                # look for the user, if we can't find it, we create it.
                purchase_user_id = Users.search([('oauth_uid', '=', str(user_id))], limit=1)

                request.env['loempia.module.purchase'].sudo().create({
                    'order_id': order_id,
                    'order_name': order_name,
                    'module_id': module.id,
                    'template_id': module.template_id.id,
                    'referrer_module_id': referrer_module_id,
                    'date_order': datetime.now(),
                    'price_unit': module.price_single,
                    'quantity': 1,
                    'state': 'draft',
                    'product_id': module.product_id,
                    'user_id': purchase_user_id.id,
                })
        return json.dumps(vals_list)

    @from_role('accounts')
    @http.route('/apps/update_module_info', type='json', auth='public')
    def update_module_info(self, created_products, **kw):
        Modules = request.env['loempia.module'].sudo()
        for vals in created_products:
            module_id = vals['module_id']
            product_id = vals['product_id']
            Modules.browse(module_id).write({'product_id': product_id})
        return 'OK'
